/**********************************
Plugin : JS Slideshow
Project : JS Autoz Vehicle slideshow
Author : Shoaib Rehmat Ali
Created : 05-Aug-2014
***********************************/

(function( $ ) {
 
    $.fn.jsslideshow = function( options ) {
 
		var settings = $.extend({
            // These are the defaults.
            panelWidth: 900, // Image panel Width
            panelHeight: 400, // Image panel Height
            speed: 500, // animation speed
            delay: 1000, // animation delay
        }, options );

		return this.each(function(){

			var parent = this;
			var currentImage = 0;
			var images = [];
			var totalImages = 0;
			var slideCounter = 0;
			var totalSlides = 0;
			var timer = 0;
			var imageMarginRight = 10;
			var imageBorderWidth = 4;

			$(parent).find('div.frameslides').find('img').each(function(){
				$(this).attr('data-imagnum',totalImages);
				var property = [];
				property.imagesrc = $(this).attr('data-lg-src');
				property.title = $(this).attr('data-title');
				property.loc = $(this).attr('data-loc');
				property.fuel = $(this).attr('data-fuel');
				property.mileage = $(this).attr('data-mileage');
				property.price = $(this).attr('data-price');
				property.condition = $(this).attr('data-condition');
				property.link = $(this).attr('data-link');
				images.push(property);
				totalImages++;
			});			

			imageMarginRight = parseInt($(parent).find('div.frameslides').find('img:first-child').css('marginRight'));
			var imageHeight = parseInt($(parent).find('div.frameslides').find('img:first-child').height());
			var imageWidth = parseInt($(parent).find('div.frameslides').find('img:first-child').width());
			imageBorderWidth = parseInt($(parent).find('div.frameslides').find('img:first-child').css('borderWidth')) * 2;
			$(parent).find('div.frameslides').height(imageHeight);
			var totalMargin = imageMarginRight * totalImages;
			var totalWidth = totalMargin + ((imageWidth + imageBorderWidth) * totalImages);
			$(parent).find('div.frameslides').width(totalWidth);
			
			var frameWidth = $(parent).find('div.frame').width();
			totalSlides = Math.floor(totalWidth / frameWidth);
			
			var leftHandle = $(parent).find('span.js-left');
			var rightHandle = $(parent).find('span.js-right');

			var divSlidesHeight = $(parent).find('div.frame').height();
			$(leftHandle).height(divSlidesHeight).css({'line-height':divSlidesHeight+'px'});
			$(rightHandle).height(divSlidesHeight).css({'line-height':divSlidesHeight+'px'});

			$(leftHandle).click(function(e){
				e.preventDefault();
				if(!$(parent).find('div.frameslides').is(':animated')){
					var marginLeft = $(parent).find('div.frameslides').css('marginLeft');
					marginLeft = Math.abs(parseInt(marginLeft));
					if(marginLeft != 0){
						margin = parseInt($(parent).find('div.frame').width()) - marginLeft;
						$(parent).find('div.frameslides').stop(true,true).animate({'marginLeft':margin},settings.speed,"linear");
						slideCounter--;
					}
				}
			});

			$(rightHandle).click(function(e){
				e.preventDefault();
				if(!$(parent).find('div.frameslides').is(':animated')){
					var marginLeft = $(parent).find('div.frameslides').css('marginLeft');
					marginLeft = Math.abs(parseInt(marginLeft));
					if(slideCounter < totalSlides){
						margin = parseInt($(parent).find('div.frame').width()) + marginLeft;
						$(parent).find('div.frameslides').stop(true,true).animate({'marginLeft':"-"+margin},settings.speed,"linear");
						slideCounter++;
					}
				}
			});

			//Slideshow
			$(parent).find('div.panel').width(settings.panelWidth).height(settings.panelHeight);
			function setTimer(){
				timer = setTimeout(function(){slideImage();},settings.delay);
			}
					
			slideImage();
			function updateCurrentImage(){
				$(parent).find('div.frameslides').find('img.currentImage').removeClass('currentImage');
				$(parent).find('div.frameslides').find('img[data-imagnum="'+currentImage+'"]').addClass('currentImage');
			}

			$(parent).find('div.panel').hover(function(ev){
			    clearInterval(timer);
			}, function(ev){
			    setTimer();
			});			
			
			$(parent).find('div.frameslides').find('img').click(function(e){
				e.preventDefault();
				var img = $(parent).find('img#loading').clone();
				$(parent).find('div.panel').find('div:first-child').append(img);
				currentImage = $(this).attr('data-imagnum');
				clearInterval(timer);
				setTimer();
			});

			function setSlider(){				
				var imageNumbers = Math.floor((slideCounter+1) * (frameWidth / (imageWidth + imageMarginRight + imageBorderWidth)));
				if(imageNumbers > totalImages) imageNumbers = totalImages - 1;
				var percentImage = Math.ceil(imageNumbers * .95);
				if(currentImage >= percentImage){
					if(slideCounter < totalSlides){
						$(rightHandle).click();
					}
				}else if(currentImage == 0){
					$(parent).find('div.frameslides').stop(true,true).animate({'marginLeft':0},10,"linear");
					slideCounter = 0;
				}
			}
			function slideImage(){
				var imageObject = images[currentImage];
				var anchor = $('<a>').attr('href',imageObject.link).css({'display':'inline-block','width':'100%'});
				var mainDiv = $('<div>').width(settings.panelWidth).height(settings.panelHeight);
				$(anchor).append(mainDiv);
				var mainImage = $("<img />").attr({'src':imageObject.imagesrc,'id':'jsslideshowimage'})
								    .load(function() {
								        if (!this.complete || typeof this.naturalWidth == "undefined" || this.naturalWidth == 0) {
								            alert('broken image!');
								        } else {
								            //$(parent).find('img#jsimgslideimage').replaceWith(img);
								        }
								}).css({'width':'100%','height':'100%'});
			    $(mainDiv).append(mainImage);
				var topDiv = $('<div>').addClass('js_topbar');
				var spanTitle = $('<span>').addClass('js_topbar_title').html(imageObject.title);
				var spanLoc = $('<span>').addClass('js_topbar_loc').html(imageObject.loc);
				$(topDiv).append(spanTitle,spanLoc);
				var bottomDiv = $('<div>').addClass('js_bottombar');
				var spanFuel = $('<span>').addClass('js_bottombar_fuel').html(imageObject.fuel).append('<span class="logo">');
				var spanMileage = $('<span>').addClass('js_bottombar_mileage').html(imageObject.mileage).append('<span class="logo">');
				var spanCondition = $('<span>').addClass('js_bottombar_condition').html(imageObject.condition).append('<span class="logo">');
				var spanPrice = $('<span>').addClass('js_bottombar_price').html(imageObject.price).append('<span class="logo">');
				$(bottomDiv).append(spanFuel,spanCondition,spanPrice,spanMileage);
				$(mainDiv).append(topDiv).append(bottomDiv);
				$(parent).find('div.panel').html(anchor);				
				var percentage = 0;
				var scale = 100;
				var fieldcounter = 0;
				if(imageObject.fuel.length != 0){
					fieldcounter++;
					scale = 100/fieldcounter;
				}
				if(imageObject.condition.length != 0){
					fieldcounter++;
					scale = 100/fieldcounter;
				}
				if(imageObject.price.length != 0){
					fieldcounter++;
					scale = 100/fieldcounter;
				}
				if(imageObject.mileage.length != 0){
					fieldcounter++;
					scale = 100/fieldcounter;
				}
				var firstFlag = 1;
				var motionSpeed = settings.delay / 10;
				var divSpeed = settings.delay / 18;
				var topheight = settings.panelHeight - 280;
				$(topDiv).animate({'top':0},divSpeed,function(){
					$(bottomDiv).animate({'left':-400},divSpeed,function(){
						if(imageObject.fuel.length != 0){
							if(firstFlag == 1){
								percentage = 0;
								firstFlag = 0;
							}else
								percentage += scale;
						}
						$(spanFuel).show().animate({'left':410},motionSpeed,'easeOutBack',function(){
							topheight += 70;
							if(imageObject.fuel.length != 0){
								$(this).find('span.logo').css({'left':"5px",'top':'5px'}).animate({'width':'40px','height':'40px'},100);
							}
							if(imageObject.condition.length != 0){
								if(firstFlag == 1){
									percentage = 0;
									firstFlag = 0;
								}else
							 		percentage += scale;
							}
							$(spanCondition).show().animate({'left':410},motionSpeed,'easeOutBack',function(){
								topheight += 70;
								if(imageObject.condition.length != 0){
									$(this).find('span.logo').css({'left':"5px",'top':'5px'}).animate({'width':'40px','height':'40px'},100);
								}
								if(imageObject.price.length != 0){
									if(firstFlag == 1){
										percentage = 0;
										firstFlag = 0;
									}else
										percentage += scale;
								}
								$(spanPrice).show().animate({'left':410},motionSpeed,'easeOutBack',function(){
									topheight += 70;
									if(imageObject.price.length != 0){
										$(this).find('span.logo').css({'left':"5px",'top':'5px'}).animate({'width':'40px','height':'40px'},100);
									}
									if(imageObject.mileage.length != 0){
										if(firstFlag == 1){
											percentage = 0;
											firstFlag = 0;
										}else
											percentage += scale;
									}
									$(spanMileage).show().animate({'left':410},motionSpeed,'easeOutBack',function(){
										if(imageObject.mileage.length != 0){
											$(this).find('span.logo').css({'left':"5px",'top':'5px'}).animate({'width':'40px','height':'40px'},100);
										}
									});
								});
							});
						});
					});
				});

				updateCurrentImage();
				setSlider();
				currentImage++;
				if(currentImage >= totalImages)
					currentImage = 0;
				setTimer();

			}

		});
	
    };
 
}( jQuery ));


